/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2015, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */
#pragma once

#include <mrpt/config.h>
#if MRPT_ENABLE_PRECOMPILED_HDRS

// Observations:
#include <mrpt/obs/CObservation.h>
#include <mrpt/obs/CAction.h>

// Very basic classes for maps:
#include <mrpt/maps/CMetricMap.h>

#include <mrpt/utils/CStream.h> // Will be used in all serialized classes (most of them in mrpt-obs)

#endif

